Examples
========

See the following examples for demonstrations
of how ``nengo_spa`` works.

.. toctree::

   examples/convolution
   examples/associative-memory
   examples/question
   examples/question-control
   examples/question-memory
   examples/spa-sequence
   examples/spa-sequence-routed
   examples/spa-parser
   examples/vocabulary-casting
